@@ -26,15 +26,15 @@ get_files (gpointer data)
 	char *s, **strv;
 	int i;
 
-	s = gnome_file_selector_open (NULL, FALSE, NULL, "/etc");
+	s = gnome_file_selector_open (NULL, FALSE, NULL, NULL, "/etc");
 	g_print ("open test:\n\t%s\n", s);
 	g_free (s);
 
-	s = gnome_file_selector_save (NULL, FALSE, NULL, "/tmp", NULL);
+	s = gnome_file_selector_save (NULL, FALSE, NULL, NULL, "/tmp", NULL);
 	g_print ("save test:\n\t%s\n", s);
 	g_free (s);
 
-	strv = gnome_file_selector_open_multi (NULL, TRUE, NULL, NULL);
+	strv = gnome_file_selector_open_multi (NULL, TRUE, NULL, NULL, NULL);
 	g_print ("open multi test:\n");
 	if (strv) {
 		for (i = 0; strv[i]; i++)
